TotalPhase Aardvark Python API
==============================

This package provides the TotalPhase Aardvark Python API modified for easy distribution via PyPI.

These files have been authorized for modification and distribution by Flying Camp Design with permission from Total Phase, Inc.  Please refer to LICENSE.txt for the Total Phase license agreement which governs the use of the provided API files.
